==> tine20-allinone_2019.12.5.tar.bz2: ActiveSync/js/ActiveSync-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: zh_CN\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "SyncDevice, SyncDevices"
: [
  ""

]
, "Sync Devices"
: ""

, "ID"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "AS Version"
: ""

, "Useragent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendarfilter"
: ""

, "Contactsfilter"
: ""

, "Emailfilter"
: ""

, "Tasksfilter"
: ""

, "Last Ping"
: ""

, "Remote Reset Device"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device is reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Device, Devices"
: [
  "设备"

]
, "Devices"
: "设备"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "选择一个设备"

, "No ActiveSync Device registered"
: "没有同步设备"

, "Set as {0} Filter"
: "设置为{0}过滤器"

, "Resetted Sync Filter"
: "重置同步过滤器"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} 过滤设备 \"{1}\" 现在是 \"{2}\""

, "resetted"
: "重新设置"

, "Set Sync Filter"
: "设置同步过滤器"

, "Default Addressbook"
: "缺省地址簿"

, "The default addressbook to create new contacts in."
: "使用默认通讯录创建新的联系人"

, "Default Calendar"
: "缺省日历"

, "The default calendar to create new events in."
: "使用缺省日历创建新的事件"

, "Default Task List"
: "任务列表"

, "The default task list to create new tasks in."
: "在默认的任务列表中创建新的任务。"

, "Default policy for new devices"
: "新设备使用默认策略"

, "Enter the id of the policy to apply to newly created devices."
: "输入ID的策略应用到新创建的设备。"

, "Disable Access Log"
: ""

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for emails"
: ""

, "For how long in the past the emails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Default Policy"
: "默认策略"

, "Default Policy installed during setup"
: "安装过程中使用默认策略"

, "SyncDevice"
: ""

, "Device"
: "设备"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: ActiveSync/js/ActiveSync-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "缺省日历"

, "The default calendar to create new events in."
: "使用缺省日历创建新的事件"

, "Default Task List"
: "任务列表"

, "The default task list to create new tasks in."
: "在默认的任务列表中创建新的任务。"

, "Sync Devices"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Sync Device, Sync Devices"
: [
  ""

]
, "Device, Devices"
: [
  "设备"

]
, "Devices"
: "设备"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "选择一个设备"

, "No ActiveSync Device registered"
: "没有同步设备"

, "Set as {0} Filter"
: "设置为{0}过滤器"

, "Resetted Sync Filter"
: "重置同步过滤器"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} 过滤设备 \"{1}\" 现在是 \"{2}\""

, "resetted"
: "重新设置"

, "Set Sync Filter"
: "设置同步过滤器"

, "ID"
: ""

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Default Policy"
: "默认策略"

, "Default Policy installed during setup"
: "安装过程中使用默认策略"

, "Default policy for new devices"
: "新设备使用默认策略"

, "Enter the id of the policy to apply to newly created devices."
: "输入ID的策略应用到新创建的设备。"

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: ""

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""



, "Sync Device"
: ""

, "Device"
: "设备"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
